@@ -6,7 +6,7 @@ import pprint
 from __version__ import __version__
 from context import *
 from nsrdb_cli import nsrdb
-from nsrdb_cli import get_nsrdb_data
+from nsrdb_cli import nsrdb_data
 from sam_simulation_cli import sam
 
 
